Summary:        Tools for JSON Object Signing and Encryption (JOSE)
Name:           jose
Version:        11
Release:        8%{?dist}

License:        ASL 2.0
URL:            https://github.com/latchset/%{name}
Source0:        https://github.com/latchset/%{name}/releases/download/v%{version}/%{name}-%{version}.tar.xz

# Fix CVE-2023-50967
Patch0001:      Fix-potential-DoS-issue-with-p2c-header.patch

BuildRequires:  gcc meson ninja-build pkgconfig
BuildRequires:  jansson-devel >= 2.10
BuildRequires:  openssl-devel zlib-devel
BuildRequires:  asciidoc

Requires: lib%{name} = %{version}-%{release}

%description
José is a C-language implementation of the Javascript Object Signing
and Encryption standards. Specifically, José aims towards implementing
the following standards:

RFC 7515 - JSON Web Signature (JWS)
RFC 7516 - JSON Web Encryption (JWE)
RFC 7517 - JSON Web Key (JWK)
RFC 7518 - JSON Web Algorithms (JWA)
RFC 7519 - JSON Web Token (JWT)
RFC 7520 - Examples of ... JOSE
RFC 7638 - JSON Web Key (JWK) Thumbprint

%package -n lib%{name}
Summary:        Library implementing JSON Object Signing and Encryption
Provides:       lib%{name}-openssl = %{version}-%{release}
Provides:       lib%{name}-zlib = %{version}-%{release}

%description -n lib%{name}
This package contains a C library for performing JOSE operations.

%package -n lib%{name}-devel
Summary:        Development files for lib%{name}
Requires:       lib%{name} = %{version}-%{release}
Requires:       pkgconfig
Requires:       jansson-devel
Provides:       lib%{name}-openssl-devel = %{version}-%{release}
Provides:       lib%{name}-zlib-devel = %{version}-%{release}

%description -n lib%{name}-devel
This package contains development files for lib%{name}.

%prep
%autosetup -p1

%build
%meson
%meson_build

%install
%meson_install
rm -rf %{buildroot}/%{_libdir}/lib%{name}.la

%check
%meson_test

%files
%license COPYING
%{_bindir}/%{name}
%{_mandir}/man1/jose*.1*

%files -n lib%{name}
%license COPYING
%{_libdir}/lib%{name}.so.*

%files -n lib%{name}-devel
%dir %{_includedir}/%{name}
%{_includedir}/%{name}/*.h
%{_libdir}/lib%{name}.so
%{_libdir}/pkgconfig/%{name}.pc
%{_mandir}/man3/jose*.3*

%changelog
* Fri Aug 16 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11-8
- Rebuilt for loongarch release

* Thu Jun 20 2024 Anakin Zhang <anakinzhang@tencent.com> - 11-7
- [TYPE] security
- [DESC] Fix CVE-2023-50967

* Tue Mar 19 2024 Rebuild Robot <rebot@opencloudos.org> - 11-6
- Rebuilt for jansson

* Fri Sep 08 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11-5
- Rebuilt for OpenCloudOS Stream 23.09

* Fri Apr 28 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11-4
- Rebuilt for OpenCloudOS Stream 23.05

* Fri Mar 31 2023 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 11-3
- Rebuilt for OpenCloudOS Stream 23

* Tue Jan 10 2023 cunshunxia <cunshunxia@tencent.com> - 11-2
- fix wrong version in spec

* Tue Nov 29 2022 cunshunxia <cunshunxia@tencent.com> - 11-1
- initial build
